etler
=====

.. image:: https://img.shields.io/pypi/v/etler.svg
    :target: https://pypi.python.org/pypi/etler
    :alt: Latest PyPI version

.. image:: https://travis-ci.org/sdll/etler.png
   :target: https://travis-ci.org/sdll/etler
   :alt: Latest Travis CI build status

ETL Utilities

Usage
-----

Installation
------------

Requirements
^^^^^^^^^^^^

Compatibility
-------------

Licence
-------

MIT
